from django.db import models


class Estate(models.Model):
    id = models.CharField(primary_key=True, max_length=200)
    created_at = models.DateTimeField("Created date")
    price = models.FloatField("Price")



from .models import Estate
from django.shortcuts import render


def index(request):
    estates = Estate.objects.order_by('-created_at')
    return render(request, 'sreality.html', {'estates': estates, 'header': "Sreality"})
